# Transitions

Transition effects for moving between clips. All transitions inherit from
the `Transition` base class.

## Base

::: pymotion.transition.base.Transition

## Fade and Dissolve

::: pymotion.transition.library.Fade

::: pymotion.transition.library.FadeToBlack

::: pymotion.transition.library.FadeToWhite

::: pymotion.transition.library.CrossDissolve

::: pymotion.transition.library.DipToColor

## Slide

::: pymotion.transition.library.SlideLeft

::: pymotion.transition.library.SlideRight

::: pymotion.transition.library.SlideUp

::: pymotion.transition.library.SlideDown

## Push

::: pymotion.transition.library.PushLeft

::: pymotion.transition.library.PushRight

::: pymotion.transition.library.PushUp

::: pymotion.transition.library.PushDown

## Cover

::: pymotion.transition.library.CoverLeft

::: pymotion.transition.library.CoverRight

::: pymotion.transition.library.CoverUp

::: pymotion.transition.library.CoverDown

## Reveal

::: pymotion.transition.library.RevealLeft

::: pymotion.transition.library.RevealRight

::: pymotion.transition.library.RevealUp

::: pymotion.transition.library.RevealDown

## Wipe

::: pymotion.transition.library.WipeLeft

::: pymotion.transition.library.WipeRight

::: pymotion.transition.library.WipeDiagonal

::: pymotion.transition.library.CircularWipe

## Zoom

::: pymotion.transition.library.ZoomIn

::: pymotion.transition.library.ZoomOut

::: pymotion.transition.library.ZoomBlur

::: pymotion.transition.library.ScaleDissolve

## Iris

::: pymotion.transition.library.IrisIn

::: pymotion.transition.library.IrisOut

## Stylized

::: pymotion.transition.library.Glitch

::: pymotion.transition.library.FilmBurn

::: pymotion.transition.library.PixelDissolve

::: pymotion.transition.library.MorphWarp

::: pymotion.transition.library.Shatter

::: pymotion.transition.library.PageTurn

::: pymotion.transition.library.Vortex

## Cut

::: pymotion.transition.library.Cut
